package com.fs.app.controller;

import com.alibaba.fastjson.JSON;
import com.fs.app.annotation.Login;
import com.fs.common.core.domain.R;
import com.fs.common.exception.CustomException;
import com.fs.company.domain.CompanyTag;
import com.fs.company.service.ICompanyTagService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@Api(tags = "企业标签接口")
@RestController
@RequestMapping("/app/companyTag")
@AllArgsConstructor
public class CompanyTagController extends AppBaseController {

    private final ICompanyTagService companyTagService;

    /**
     * 查询公司标签列表
     */
    @Login
    @GetMapping("/list")
    @ApiOperation("查询公司标签列表")
    public R list() {
        CompanyTag companyTag = new CompanyTag();
        companyTag.setCompanyId(getCompanyId());
        List<CompanyTag> list = companyTagService.selectCompanyTagList(companyTag);
        return R.ok().put("data", list);
    }

    /**
     * 新增公司标签
     */
    @Login
    @PostMapping("/add")
    @ApiOperation("新增公司标签")
    public R add(@RequestBody CompanyTag companyTag) throws CustomException {
        log.debug("新增公司标签 companyTag: {}", JSON.toJSONString(companyTag));
        companyTag.setCompanyId(getCompanyId());
        companyTagService.insertCompanyTag(companyTag);
        return R.ok();
    }

    /**
     * 删除公司标签
     */
    @Login
    @PostMapping("/delete")
    @ApiOperation("删除公司标签")
    public R remove(@RequestParam List<Long> tagIds) {
        log.debug("删除公司标签 tagIds: {}", tagIds);
        companyTagService.deleteCompanyTagByTagIds(tagIds);
        return R.ok();
    }
}
