package com.fs.app.controller;

import com.fs.app.annotation.Login;
import com.fs.app.vo.CompanySubUserVO;
import com.fs.common.core.domain.R;
import com.fs.common.utils.bean.BeanUtils;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyUserService;
import com.fs.course.service.IFsCourseRedPacketLogService;
import com.fs.course.service.IFsCourseWatchLogService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Api(tags = "企业用户接口")
@RestController
@RequestMapping("/app/companyUser")
@AllArgsConstructor
public class CompanyUserController extends AppBaseController {

    private final ICompanyUserService companyUserService;
    private final IFsCourseWatchLogService courseWatchLogService;
    private final IFsCourseRedPacketLogService courseRedPacketLogService;

    @Login
    @ApiOperation("下级用户列表")
    @GetMapping("/getCompanyUserList")
    public R getCompanyUserList(@RequestParam(required = false, defaultValue = "1") Integer pageNum,
                                @RequestParam(required = false, defaultValue = "10") Integer pageSize) {
        log.debug("下级用户列表 pageNum: {}, pageSize: {}", pageNum, pageSize);
        PageHelper.startPage(pageNum, pageSize);
        List<CompanyUser> companyUsers = companyUserService.selectCompanySubUserList(Long.parseLong(getUserId()));
        PageInfo<CompanyUser> page = new PageInfo<>(companyUsers);

        List<CompanySubUserVO> users = page.getList().stream().map(u -> {
            CompanySubUserVO vo = new CompanySubUserVO();
            BeanUtils.copyProperties(u, vo);

            Map<String, Object> params = new HashMap<>();
            params.put("date", LocalDate.now());
            params.put("companyUserId", u.getUserId());
            params.put("logTypes", Arrays.asList(1,2,4));

            // 今日观看人数
            int count = courseWatchLogService.countByMap(params);
            vo.setTodayWatchCount(count);

            // 今日完播人数
            params.put("logTypes", Collections.singletonList(2));
            int finishCount = courseWatchLogService.countByMap(params);
            vo.setTodayFinishCount(finishCount);

            // 今日完播率
            BigDecimal rate = count > 0 ? BigDecimal.valueOf(finishCount)
                    .divide(BigDecimal.valueOf(count), 2, RoundingMode.HALF_UP)
                    .multiply(BigDecimal.valueOf(100)) : BigDecimal.ZERO;
            vo.setTodayFinishRate(rate);

            // 今日红包金额
            BigDecimal amount = courseRedPacketLogService.getSumByCompanyUserIdId(u.getUserId());
            vo.setTodayRedPacketAmount(amount);

            return vo;
        }).collect(Collectors.toList());

        PageInfo<CompanySubUserVO> pageInfo = new PageInfo<>(users);
        BeanUtils.copyProperties(page, pageInfo);

        return R.ok().put("data", pageInfo);
    }

}
